% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/glass_tabs.R
\name{glassTabsUI}
\alias{glassTabsUI}
\title{Animated glass-style tab navigation UI}
\usage{
glassTabsUI(
  id,
  ...,
  selected = NULL,
  wrap = TRUE,
  extra_ui = NULL,
  theme = NULL
)
}
\arguments{
\item{id}{Module namespace id.}

\item{...}{One or more \code{\link[=glassTabPanel]{glassTabPanel()}} objects.}

\item{selected}{Value of the initially selected tab.}

\item{wrap}{Logical. When \code{TRUE} wraps everything in a \code{div.gt-container}.}

\item{extra_ui}{Optional additional UI placed to the right of the tab bar.}

\item{theme}{One of \code{"dark"}, \code{"light"}, or a \code{\link[=glass_tab_theme]{glass_tab_theme()}} object.}
}
\value{
An \code{htmltools::tagList} ready to use in a Shiny UI.
}
\description{
Animated glass-style tab navigation UI
}
