% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/glass_tab_theme.R
\name{glass_tab_theme}
\alias{glass_tab_theme}
\title{Create a custom color theme for glassTabsUI}
\usage{
glass_tab_theme(
  tab_text = NULL,
  tab_active_text = NULL,
  halo_bg = NULL,
  halo_border = NULL,
  content_bg = NULL,
  content_border = NULL,
  card_bg = NULL,
  card_text = NULL
)
}
\arguments{
\item{tab_text}{Inactive tab text color.}

\item{tab_active_text}{Active tab text color.}

\item{halo_bg}{Halo background.}

\item{halo_border}{Halo border.}

\item{content_bg}{Tab content background.}

\item{content_border}{Tab content border.}

\item{card_bg}{Inner card background.}

\item{card_text}{Inner card text color.}
}
\value{
A named list of class \code{"glass_tab_theme"}.
}
\description{
Create a custom color theme for glassTabsUI
}
